@@ -101,6 +101,10 @@ mchar__init ()
   Mbidi_category = msymbol ("bidirectional-category");
   Msimple_case_folding = msymbol ("simple-case-folding");
   Mcomplicated_case_folding = msymbol ("complicated-case-folding");
+  Mcased = msymbol ("cased");
+  Msoft_dotted = msymbol ("soft-dotted");
+  Mcase_mapping = msymbol ("case-mapping");
+  Mblock = msymbol ("block");
   Mscript = msymbol ("script");
 
   return 0;
@@ -200,6 +204,8 @@ mchar__define_prop (MSymbol key, MSymbol type, void *mdb)
     @name ѿ: ʸץѥƥΥ
 
     ΥܥʸץѥƥΥȤƻȤ롣*/
+
+/*=*/
 /*** @{ */
 
 /***en
@@ -346,6 +352,8 @@ MSymbol Mbidi_category;
     Ȥʸץѥƥġ  */
 
 MSymbol Msimple_case_folding;
+/*=*/
+
 /***en
     @brief Key for corresponding multiple lowercase characters.
 
@@ -367,6 +375,86 @@ MSymbol Msimple_case_folding;
 
 MSymbol Mcomplicated_case_folding;
 /*=*/
+
+/***en
+    @brief Key for values used in case operation.
+
+    The symbol #Mcased has the name <tt>"cased"</tt> and is used as
+    the key of charater property.  The value of such a property is an
+    integer value 1, 2, or 3 representing "cased", "case-ignorable",
+    and both of them respective.  See the Unicode Standard 5.0
+    (Section 3.13 Default Case Algorithm) for the detail.
+ */
+
+/***ja
+    @brief Case ѤͤΥ.
+
+    ܥ #Mcased ϡ<tt>"cased"</tt> Ȥ̾ʸץ
+    ƥΥȤƻȤ롣Υץѥƥͤ 1, 2, 3 Τ
+    줫Ǥꡢ줾 "cased", "case-ignorable", ξ̣롣
+    ܺ٤ˤĤƤϡthe Unicode Standard 5.0 (Section 3.13 Default
+    Case Algorithm) ȡ
+ */
+MSymbol Mcased;
+
+/*=*/
+/***en
+    @brief Key for values used in case operation.
+
+    The symbol #Msoft_dotted has the name <tt>"soft-dotted"</tt> and
+    is used as the key of charater property.  The value of such a
+    property is #Mt if a character has "Soft_Dotted" property, and
+    #Mnil otherwise.  See the Unicode Standard 5.0 (Section 3.13
+    Default Case Algorithm) for the detail.  */
+
+/***ja
+    @brief Case ѤͤΥ.
+
+    ܥ #Msoft_dotted ϡ<tt>"soft-dotted"</tt> Ȥ̾
+    ʸץѥƥΥȤƻȤ롣Υץѥƥͤϡʸ
+    "Soft_Dotted"ץѥƥľˤ #Mt, Ǥʤ #Mnil 
+    롣 ܺ٤ˤĤƤϡthe Unicode Standard 5.0 (Section 3.13
+    Default Case Algorithm) ȡ
+ */
+MSymbol Msoft_dotted;
+
+/*=*/
+/***en 
+    @brief Key for values used in case operation.
+
+    The symbol #Mcase_mapping has the name <tt>"case-mapping"</tt> and
+    is used as the key of charater property.  The value of such a
+    property is a plist of three M-Texts; lower, title, and upper of
+    the corresponding character.  See the Unicode Standard 5.0
+    (Section 5.18 Case Mappings) for the detail.  */
+
+/***ja
+    @brief Case ѤͤΥ.
+
+    ܥ #Mcase_mapping ϡ<tt>"case-mapping"</tt> Ȥ̾
+    ʸץѥƥΥȤƻȤ롣Υץѥƥͤϡ
+     M-textʤʸ lower, title,  upperʤ plist
+    Ǥ롣 ܺ٤ˤĤƤϡthe Unicode Standard 5.0 (Section 3.13
+    Default Case Algorithm) ȡ
+*/
+MSymbol Mcase_mapping;
+
+/*=*/
+/***en 
+    @brief Key for script block name.
+
+    The symbol #Mblock the name <tt>"block"</tt> and is used as the
+    key of charater property.  The value of such a property is a
+    symbol representing a script block of the corresponding
+    character.  */
+/***ja
+    @brief ץȥ֥å̾ɽ.
+
+    ܥ #Mblock ϡ<tt>"block"</tt> Ȥ̾ʸץ
+    ƥΥȤƻȤ롣ΥץѥƥͤϡʸΥ
+    ȥ֥å̾ɽܥǤ롣*/
+MSymbol Mblock;
+
 /*** @} */
 /*=*/
 
