@@ -76,6 +76,7 @@
     ɥݥȤʸɤؤѴ @e ǥ
     ȸƤӡʸɤ饳ɥݥȤؤѴ @e 󥳡 ȸƤ֡  */
 
+
 /*=*/
 #if !defined (FOR_DOXYGEN) || defined (DOXYGEN_INTERNAL_MODULE)
 /*** @addtogroup m17nInternal
@@ -837,13 +838,6 @@ MSymbol Mcharset_binary;
 /*** @{ */
 /*=*/
 
-/***en
-    Parameter key for mchar_define_charset () (which see). */ 
-
-/***ja
-    ؿ mchar_define_charset () ѤΥѥ᡼. 
-    ܤϤδؿβ򻲾ȤΤȡ*/ 
-
 MSymbol Mmethod;
 MSymbol Mdimension;
 MSymbol Mmin_range;
@@ -867,7 +861,7 @@ MSymbol Maliases;
     @name Variables: Symbols representing charset methods.
 
     These are the predefined symbols that can be a value of the
-    #Mmethod parameter of a charset used in an argument to the
+    @b Mmethod parameter of a charset used in an argument to the
     mchar_define_charset () function.
 
     A method specifies how code-points and character codes are
@@ -878,7 +872,7 @@ MSymbol Maliases;
     @name ѿ: ʸåȤΥ᥽åɻ˻Ȥ륷ܥ
 
     ϡʸåȤ @e ᥽å ꤹ뤿ѤߥܥǤꡢʸåȤ
-    #Mmethod ѥ᡼ͤȤʤ뤳ȤǤ롣
+    @b Mmethod ѥ᡼ͤȤʤ뤳ȤǤ롣
     ͤϴؿ mchar_define_charset () ΰȤƻȤ롣
 
     ᥽åɤȤϡɥݥȤʸɤѴݤΤȤǤ롣
@@ -889,7 +883,7 @@ MSymbol Maliases;
     @brief Symbol for the offset type method of charset.
 
     The symbol #Moffset has the name <tt>"offset"</tt> and, when used
-    as a value of #Mmethod parameter of a charset, it means that the
+    as a value of @b Mmethod parameter of a charset, it means that the
     conversion of code-points and character codes of the charset is
     done by this calculation:
 
@@ -897,21 +891,21 @@ MSymbol Maliases;
 CHARACTER-CODE = CODE-POINT - MIN-CODE + MIN-CHAR
 @endverbatim
 
-    where, MIN-CODE is a value of #Mmin_code parameter of the charset,
-    and MIN-CHAR is a value of #Mmin_char parameter.  */
+    where, MIN-CODE is a value of @b Mmin_code parameter of the charset,
+    and MIN-CHAR is a value of @b Mmin_char parameter.  */
 
 /***ja
     @brief եåȷΥ᥽åɤ򼨤ܥ.
 
     ܥ #Moffset  <tt>"offset"</tt> Ȥ̾ʸåȤ
-    #Mmethod ѥ᡼ͤȤѤ줿ˤϡɥݥȤʸåȤʸɤδ֤Ѵʲμ˽äƹԤ뤳Ȥ̣롣
+    @b Mmethod ѥ᡼ͤȤѤ줿ˤϡɥݥȤʸåȤʸɤδ֤Ѵʲμ˽äƹԤ뤳Ȥ̣롣
 
 @verbatim
 ʸ = ɥݥ - MIN-CODE + MIN-CHAR
 @endverbatim
 
-    ǡMIN-CODE ʸåȤ #Mmin_code ѥ᡼ͤǤꡢMIN-CHAR 
-    #Mmin_char ѥ᡼ͤǤ롣 */
+    ǡMIN-CODE ʸåȤ @b Mmin_code ѥ᡼ͤǤꡢMIN-CHAR 
+    @b Mmin_char ѥ᡼ͤǤ롣 */
 
 MSymbol Moffset;
 /*=*/
@@ -919,16 +913,16 @@ MSymbol Moffset;
 /***en @brief Symbol for the map type method of charset.
 
     The symbol #Mmap has the name <tt>"map"</tt> and, when used as a
-    value of #Mmethod parameter of a charset, it means that the
+    value of @b Mmethod parameter of a charset, it means that the
     conversion of code-points and character codes of the charset is
-    done by map looking up.  The map must be given by #Mmapfile
+    done by map looking up.  The map must be given by @b Mmapfile
     parameter.  */
 
 /***ja @brief ޥå׷Υ᥽åɤ򼨤ܥ.
 
     ܥ #Mmap  <tt>"map"</tt> Ȥ̾ʸåȤ 
-    #Mmethod ѥ᡼ͤȤѤ줿ˤϡɥݥȤʸåȤʸɤδ֤Ѵޥåפ򻲾Ȥ뤳ȤˤäƹԤ뤳Ȥ̣롣
-    ޥåפ #Mmapfile ѥ᡼ȤͿʤФʤʤ */
+    @b Mmethod ѥ᡼ͤȤѤ줿ˤϡɥݥȤʸåȤʸɤδ֤Ѵޥåפ򻲾Ȥ뤳ȤˤäƹԤ뤳Ȥ̣롣
+    ޥåפ @b Mmapfile ѥ᡼ȤͿʤФʤʤ */
 
 MSymbol Mmap;
 /*=*/
@@ -936,10 +930,10 @@ MSymbol Mmap;
 /***en @brief Symbol for the unify type method of charset.
 
     The symbol #Munify has the name <tt>"unify"</tt> and, when used as
-    a value of #Mmethod parameter of a charset, it means that the
+    a value of @b Mmethod parameter of a charset, it means that the
     conversion of code-points and character codes of the charset is
     done by map looking up and offsetting.  The map must be given by
-    #Mmapfile parameter.  For this kind of charset, a unique
+    @b Mmapfile parameter.  For this kind of charset, a unique
     continuous character code space for all characters is assigned.
 
     If the map has an entry for a code-point, the conversion is done
@@ -950,15 +944,15 @@ MSymbol Mmap;
 CHARACTER-CODE = CODE-POINT - MIN-CODE + LOWEST-CHAR-CODE
 @endverbatim
 
-    where, MIN-CODE is a value of #Mmin_code parameter of the charset,
+    where, MIN-CODE is a value of @b Mmin_code parameter of the charset,
     and LOWEST-CHAR-CODE is the lowest character code of the assigned
     code space.  */
 
 /***ja @brief ˥եΥ᥽åɤ򼨤ܥ.
 
     ܥ #Minherit  <tt>"unify"</tt> Ȥ̾ʸåȤ 
-    #Mmethod ѥ᡼ͤȤѤ줿ˤϡɥݥȤʸåȤʸɤδ֤ѴޥåפλȤȥեåȤȤ߹碌ˤäƹԤ뤳Ȥ̣롣
-    ޥåפ #Mmapfile ѥ᡼ȤͿʤФʤʤ
+    @b Mmethod ѥ᡼ͤȤѤ줿ˤϡɥݥȤʸåȤʸɤδ֤ѴޥåפλȤȥեåȤȤ߹碌ˤäƹԤ뤳Ȥ̣롣
+    ޥåפ @b Mmapfile ѥ᡼ȤͿʤФʤʤ
     μγʸåȤˤϡʸФϢ³륳ɥڡ줾Ƥ롣
 
     ɥݥȤޥåפ˴ޤޤƤСѴϥޥå׻ȤˤäƹԤ롣
@@ -968,7 +962,7 @@ CHARACTER-CODE = CODE-POINT - MIN-CODE + LOWEST-CHAR-CODE
 CHARACTER-CODE = CODE-POINT - MIN-CODE + LOWEST-CHAR-CODE
 @endverbatim
     
-    ǡMIN-CODE ʸåȤ #Mmin_code ѥ᡼ͤǤꡢ
+    ǡMIN-CODE ʸåȤ @b Mmin_code ѥ᡼ͤǤꡢ
     LOWEST-CHAR-CODE ϳƤ줿ɥڡκǤ⾮ʸɤǤ롣
     */
 
@@ -979,9 +973,9 @@ MSymbol Munify;
     @brief Symbol for the subset type method of charset.
 
     The symbol #Msubset has the name <tt>"subset"</tt> and, when used
-    as a value of #Mmethod parameter of a charset, it means that the
+    as a value of @b Mmethod parameter of a charset, it means that the
     charset is a subset of a parent charset.  The parent charset must
-    be given by #Mparents parameter.  The conversion of code-points
+    be given by @b Mparents parameter.  The conversion of code-points
     and character codes of the charset is done conceptually by this
     calculation:
 
@@ -996,8 +990,8 @@ CHARACTER-CODE = PARENT-CODE (CODE-POINT) + SUBSET-OFFSET
 /***ja @brief ֥åȷΥ᥽åɤ򼨤ܥ.
 
     ܥ #Msubset  <tt>"subset"</tt> Ȥ̾ʸåȤ
-    #Mmethod ѥ᡼ͤȤѤ줿ˤϡʸåȤ̤ʸåȡʿʸåȡˤʬǤ뤳Ȥ̣롣
-    ʸåȤ #Mparents ѥ᡼ˤäͿʤƤϤʤʤ
+    @b Mmethod ѥ᡼ͤȤѤ줿ˤϡʸåȤ̤ʸåȡʿʸåȡˤʬǤ뤳Ȥ̣롣
+    ʸåȤ @b Mparents ѥ᡼ˤäͿʤƤϤʤʤ
     ɥݥȤʸåȤʸɤδ֤ѴϡǰŪˤϰʲμ˽
 
 @verbatim
@@ -1006,7 +1000,7 @@ CHARACTER-CODE = PARENT-CODE (CODE-POINT) + SUBSET-OFFSET
 
      PARENT-CODE  CODE-POINT 
     οʸåǤʸɤ֤ؿǤꡢSUBSET-OFFSET  
-    #Msubset_offset ѥ᡼ͿͤǤ롣
+    @b Msubset_offset ѥ᡼ͿͤǤ롣
     */
 
 MSymbol Msubset;
@@ -1016,16 +1010,16 @@ MSymbol Msubset;
     @brief Symbol for the superset type method of charset.
 
     The symbol #Msuperset has the name <tt>"superset"</tt> and, when
-    used as a value of #Mmethod parameter of a charset, it means that
+    used as a value of @b Mmethod parameter of a charset, it means that
     the charset is a superset of parent charsets.  The parent charsets
-    must be given by #Mparents parameter.  */
+    must be given by @b Mparents parameter.  */
 
 /***ja
     @brief ѡåȷΥ᥽åɤ򼨤ܥ.
 
     ܥ #Msuperset  <tt>"superset"</tt> Ȥ̾ʸåȤ
-    #Mmethod ѥ᡼ͤȤѤ줿ˤϡʸåȤ̤ʸåȡʿʸåȡˤξ̽Ǥ뤳Ȥ̣롣
-    ʸåȤ #Mparents ѥ᡼ˤäͿʤƤϤʤʤ
+    @b Mmethod ѥ᡼ͤȤѤ줿ˤϡʸåȤ̤ʸåȡʿʸåȡˤξ̽Ǥ뤳Ȥ̣롣
+    ʸåȤ @b Mparents ѥ᡼ˤäͿʤƤϤʤʤ
     */
 
 MSymbol Msuperset;
@@ -1041,24 +1035,24 @@ MSymbol Msuperset;
 
     <ul>
 
-    <li> Key is #Mmethod, value is a symbol.
+    <li> Key is @b Mmethod, value is a symbol.
 
     The value specifies the method for decoding/encoding code-points
     in the charset.  It must be #Moffset, #Mmap (default), #Munify,
     #Msubset, or #Msuperset.
 
-    <li> Key is #Mdimension, value is an integer
+    <li> Key is @b Mdimension, value is an integer
 
     The value specifies the dimension of code-points of the charset.
     It must be 1 (default), 2, 3, or 4.
 
-    <li> Key is #Mmin_range, value is an unsigned integer
+    <li> Key is @b Mmin_range, value is an unsigned integer
 
     The value specifies the minimum range of a code-point, which means
     that the Nth byte of the value is the minimum Nth byte of
     code-points of the charset.   The default value is 0.
 
-    <li> Key is #Mmax_range, value is an unsigned integer
+    <li> Key is @b Mmax_range, value is an unsigned integer
 
     The value specifies the maximum range of a code-point, which means
     that the Nth byte of the value is the maximum Nth byte of
@@ -1066,29 +1060,29 @@ MSymbol Msuperset;
     0xFFFFFF, or 0xFFFFFFFF if the dimension is 1, 2, 3, or 4
     respectively.
 
-    <li> Key is #Mmin_code, value is an unsigned integer
+    <li> Key is @b Mmin_code, value is an unsigned integer
 
     The value specifies the minimum code-point of
     the charset.  The default value is the minimum range.
 
-    <li> Key is #Mmax_code, value is an unsigned integer
+    <li> Key is @b Mmax_code, value is an unsigned integer
 
     The value specifies the maximum code-point of
     the charset.  The default value is the maximum range.
 
-    <li> Key is #Mascii_compatible, value is a symbol
+    <li> Key is @b Mascii_compatible, value is a symbol
 
     The value specifies whether the charset is ASCII compatible or
     not.  If the value is #Mnil (default), it is not ASCII
     compatible, else compatible.
 
-    <li> Key is #Mfinal_byte, value is an integer
+    <li> Key is @b Mfinal_byte, value is an integer
 
     The value specifies the @e final @e byte of the charset registered
     in The International Registry.  It must be 0 (default) or 32..127.
     The value 0 means that the charset is not in the registry.
 
-    <li> Key is #Mrevision, value is an integer
+    <li> Key is @b Mrevision, value is an integer
 
     The value specifies the @e revision @e number of the charset
     registered in The International Registry.  It must be 0..127.  If
@@ -1096,12 +1090,12 @@ MSymbol Msuperset;
     ignored.  The value 0 means that the charset has no revision
     number.
 
-    <li> Key is #Mmin_char, value is an integer
+    <li> Key is @b Mmin_char, value is an integer
 
     The value specifies the minimum character code of the charset.
     The default value is 0.
 
-    <li> Key is #Mmapfile, value is an M-text
+    <li> Key is @b Mmapfile, value is an M-text
 
     If the method is #Mmap or #Munify, a data that contains
     mapping information is added to the m17n database by calling
@@ -1110,7 +1104,7 @@ MSymbol Msuperset;
 
     Otherwise, this parameter is ignored.
 
-    <li> Key is #Mparents, value is a plist
+    <li> Key is @b Mparents, value is a plist
 
     If the method is #Msubset, the value must is a plist of length
     1, and the value of the plist must be a symbol representing a
@@ -1122,7 +1116,7 @@ MSymbol Msuperset;
 
     Otherwise, this parameter is ignored.
 
-    <li> Key is #Mdefine_coding, value is a symbol
+    <li> Key is @b Mdefine_coding, value is a symbol
 
     If the dimension of the charset is 1, the value specifies whether
     or not to define a coding system of the same name whose type is
@@ -1146,62 +1140,62 @@ MSymbol Msuperset;
 
     <ul>
 
-    <li>  #Mmethod ͤܥλ
+    <li>  @b Mmethod ͤܥλ
 
     ͤϡ#Moffset, #Mmap (ǥե), #Munify, #Msubset,
     #Msuperset Τ줫ǤꡢʸåȤΥɥݥȤǥɡ󥳡ɤݤΥ᥽åɤꤹ롣
 
-    <li>  #Mdimension ͤͤλ
+    <li>  @b Mdimension ͤͤλ
 
     ͤϡ1 (ǥե), 2, 3, 4 
     Τ줫ǤꡢʸåȤΥɥݥȤμǤ롣
 
-    <li>  #Mmin_range ͤͤλ
+    <li>  @b Mmin_range ͤͤλ
 
     ͤϥɥݥȤκǾͤǤ롣ʤͤ N 
     ܤΥХȤϤʸåȤΥɥݥȤ N ܤΥХȤκǾΤΤȤʤ롣
     ǥեͤ 0 
 
-    <li>  #Mmax_range ͤͤλ
+    <li>  @b Mmax_range ͤͤλ
 
     ͤϥɥݥȤκͤǤ롣ʤͤ N 
     ܤΥХȤϤʸåȤΥɥݥȤ N ܤΥХȤκΤΤȤʤ롣
     ǥեͤϡɥݥȤμ 1, 2, 3, 4 λ줾
     0xFF, 0xFFFF, 0xFFFFFF, 0xFFFFFFFF 
 
-    <li>  #Mmin_code ͤͤλ
+    <li>  @b Mmin_code ͤͤλ
 
     ͤϤʸåȤκǾΥɥݥȤǤ롣ǥեͤ 
-    #Mmin_range ͡
+    @b Mmin_range ͡
 
-    <li>  #Mmax_code ͤͤλ
+    <li>  @b Mmax_code ͤͤλ
 
     ͤϤʸåȤκΥɥݥȤǤ롣ǥեͤ 
-    #Mmax_range ͡
+    @b Mmax_range ͡
 
-    <li>   #Mascii_compatible ͤܥλ
+    <li>   @b Mascii_compatible ͤܥλ
 
     ͤϤʸåȤ ASCII ߴǤ뤫ɤ򼨤ǥեͤ
     #Mnil ǤиߴǤϤʤʳξϸߴǤ롣
 
-    <li>   #Mfinal_byte ͤͤλ
+    <li>   @b Mfinal_byte ͤͤλ
 
     ͤϤʸåȤ The International Registry ϿƤ 
     @e üХ Ǥꡢ0 (ǥե) Ǥ뤫 32..127 Ǥ롣0 
     ϿƤʤȤ̣롣
 
-    <li>   #Mrevision ͤͤλ
+    <li>   @b Mrevision ͤͤλ
 
     ͤ The International Registry ϿƤ @e revision @e
     number Ǥꡢ0..127 Ǥ롣
     ʸåȤϿƤʤˤϤ̵ͤ뤵롣
     0  revision number ¸ߤʤȤ̣롣
 
-    <li>   #Mmin_char ͤͤλ
+    <li>   @b Mmin_char ͤͤλ
 
     ͤϤʸåȤκǾʸɤǤ롣ǥեͤ 0 
 
-    <li>  #Mmapfile ͤ M-text λ
+    <li>  @b Mmapfile ͤ M-text λ
 
     ᥽åɤ #Mmap  #Munify λؿ mdatabase_define () 
     򤳤ͤ $EXTRA_INFO ȤƸƤ֤Ȥˤäơޥåԥ󥰤˴ؤǡ
@@ -1210,7 +1204,7 @@ MSymbol Msuperset;
 
     ǤʤСΥѥ᡼̵뤵롣
 
-    <li>  #Mparents ͤ plist λ
+    <li>  @b Mparents ͤ plist λ
 
     ᥽åɤ #Msubset ʤСͤĹ 1  plist 
     ǤꡢͤϤʸåȤξ̽ȤʤʸåȤ򼨤ܥǤ롣
@@ -1220,7 +1214,7 @@ MSymbol Msuperset;
 
     ǤʤСΥѥ᡼̵뤵롣
 
-    <li>   #Mdefine_coding ͤܥλ
+    <li>   @b Mdefine_coding ͤܥλ
 
     ʸåȤμ 1 ʤСͤ #Mnil ʳξ #Mcharset 
     Ʊ̾ĥɷϤ롣
