@@ -1750,7 +1750,11 @@ mdraw__init ()
   MbidiS = msymbol ("S");
   MbidiNSM = msymbol ("NSM");
 #ifdef HAVE_FRIBIDI
+#if FRIBIDI_INTERFACE_VERSION < 3
   fribidi_set_mirroring (TRUE);
+#else
+  fribidi_set_mirroring (1);
+#endif
 #endif
 
   M_break_at_space = msymbol ("bs");
@@ -2001,7 +2005,7 @@ mdraw_image_text (MFrame *frame, MDrawWindow win, int x, int y,
     this function also follows what specified in the drawing control
     object $CONTROL.
 
-    For instance, if <two_dimensional> of $CONTROL is nonzero, this
+    For instance, if \<two_dimensional\> of $CONTROL is nonzero, this
     function draw an M-text 2-dimensionally, i.e., newlines in M-text
     breaks lines and the following characters are drawn in the next
     line.  See the documentation of the structure @ MDrawControl for
@@ -2017,7 +2021,7 @@ mdraw_image_text (MFrame *frame, MDrawWindow win, int x, int y,
     ƥȤˡ mdraw_text () ȤۤƱǤ뤬δؿѤΥ֥
     $CONTROL λؼˤ⽾ۤʤäƤ롣
 
-    Ȥ $CONTROL  <two_dimensional> ǤʤСδؿ 
+    Ȥ $CONTROL  \<two_dimensional\> ǤʤСδؿ 
     M-text 2Ūʤ M-text βԤǹԤᡢ³ʸϼιԤܺ٤Ϲ¤
     @ MDrawControl 򻲾Ȥ뤳ȡ*/
 
