@@ -2158,42 +2158,42 @@ MSymbol Mfontconfig;
 /***en
     @brief Symbol of name "x".
 
-    The variable #Mx is to be used for a value of <type> member of the
-    structure #MDrawGlyph to specify the type of <fontp> member is
+    The variable #Mx is to be used for a value of \<type\> member of the
+    structure #MDrawGlyph to specify the type of \<fontp\> member is
     actually (XFontStruct *).  */
 /***ja
     @brief "x" Ȥ̾ĥܥ.
 
-    ѿ #Mx Ϲ¤ #MDrawGlyph Υ <type> 
-    ͤȤѤ졢 <fontp> ηºݤˤ (XFontStruct *) Ǥ뤳Ȥɽ.  */
+    ѿ #Mx Ϲ¤ #MDrawGlyph Υ \<type\> 
+    ͤȤѤ졢 \<fontp\> ηºݤˤ (XFontStruct *) Ǥ뤳Ȥɽ.  */
 
 MSymbol Mx;
 
 /***en
     @brief Symbol of name "freetype".
 
-    The variable #Mfreetype is to be used for a value of <type> member
-    of the structure #MDrawGlyph to specify the type of <fontp> member
+    The variable #Mfreetype is to be used for a value of \<type\> member
+    of the structure #MDrawGlyph to specify the type of \<fontp\> member
     is actually FT_Face.  */
 /***ja
     @brief "freetype" Ȥ̾ĥܥ.
 
-    ѿ #Mfreetype Ϲ¤ #MDrawGlyph Υ <type> 
-    ͤȤѤ졢 <fontp> ηºݤˤ FT_Face Ǥ뤳Ȥɽ  */
+    ѿ #Mfreetype Ϲ¤ #MDrawGlyph Υ \<type\> 
+    ͤȤѤ졢 \<fontp\> ηºݤˤ FT_Face Ǥ뤳Ȥɽ  */
 
 MSymbol Mfreetype;
 
 /***en
     @brief Symbol of name "xft".
 
-    The variable #Mxft is to be used for a value of <type> member of the
-    structure #MDrawGlyph to specify the type of <fontp> member
+    The variable #Mxft is to be used for a value of \<type\> member of the
+    structure #MDrawGlyph to specify the type of \<fontp\> member
     is actually (XftFont *).  */
 /***ja
     @brief  "xft" Ȥ̾ĥܥ.
 
-    ѿ #Mxft Ϲ¤ #MDrawGlyph Υ <type> 
-    ͤȤѤ졢 <fontp> ηºݤˤ (XftFont *) Ǥ뤳Ȥɽ  */
+    ѿ #Mxft Ϲ¤ #MDrawGlyph Υ \<type\> 
+    ͤȤѤ졢 \<fontp\> ηºݤˤ (XftFont *) Ǥ뤳Ȥɽ  */
 
 MSymbol Mxft;
 
