@@ -17,7 +17,7 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    02111-1307, USA.  */
 
 /***en
@@ -419,23 +419,23 @@ win_callback (MInputContext *ic, MSymbol command)
     }
   else if (command == Minput_set_spot)
     {
-      minput__callback (ic, Minput_preedit_draw);
-      minput__callback (ic, Minput_status_draw);
-      minput__callback (ic, Minput_candidates_draw);
+      minput_callback (ic, Minput_preedit_draw);
+      minput_callback (ic, Minput_status_draw);
+      minput_callback (ic, Minput_candidates_draw);
     }
   else if (command == Minput_toggle)
     {
       if (ic->active)
 	{
-	  minput__callback (ic, Minput_preedit_done);
-	  minput__callback (ic, Minput_status_done);
-	  minput__callback (ic, Minput_candidates_done);
+	  minput_callback (ic, Minput_preedit_done);
+	  minput_callback (ic, Minput_status_done);
+	  minput_callback (ic, Minput_candidates_done);
 	}
       else
 	{
-	  minput__callback (ic, Minput_preedit_start);
-	  minput__callback (ic, Minput_status_start);
-	  minput__callback (ic, Minput_candidates_start);
+	  minput_callback (ic, Minput_preedit_start);
+	  minput_callback (ic, Minput_status_start);
+	  minput_callback (ic, Minput_candidates_start);
 	}
     }
   else if (command == Minput_preedit_start)
@@ -487,8 +487,8 @@ win_callback (MInputContext *ic, MSymbol command)
 
       if (minput_default_driver.callback_list
 	  && (func = ((MInputCallbackFunc)
-		      mplist_get (minput_default_driver.callback_list,
-				  Minput_reset))))
+		      mplist_get_func (minput_default_driver.callback_list,
+				       Minput_reset))))
 	{
 	  MInputContextInfo *ic_info
 	    = (MInputContextInfo *) win_ic_info->ic_info;
@@ -497,11 +497,11 @@ win_callback (MInputContext *ic, MSymbol command)
 	  ic->info = win_ic_info;
 	}
       if (ic->preedit_changed)
-	minput__callback (ic, Minput_preedit_draw);
+	minput_callback (ic, Minput_preedit_draw);
       if (ic->status_changed)
-	minput__callback (ic, Minput_status_draw);
+	minput_callback (ic, Minput_status_draw);
       if (ic->candidates_changed)
-	minput__callback (ic, Minput_candidates_draw);
+	minput_callback (ic, Minput_candidates_draw);
     }
 }
 
@@ -533,18 +533,18 @@ minput__win_init ()
     MPlist *plist = mplist ();
 
     minput_gui_driver.callback_list = plist;
-    plist = mplist_add (plist, Minput_preedit_start, (void *) win_callback);
-    plist = mplist_add (plist, Minput_preedit_draw, (void *) win_callback);
-    plist = mplist_add (plist, Minput_preedit_done, (void *) win_callback);
-    plist = mplist_add (plist, Minput_status_start, (void *) win_callback);
-    plist = mplist_add (plist, Minput_status_draw, (void *) win_callback);
-    plist = mplist_add (plist, Minput_status_done, (void *) win_callback);
-    plist = mplist_add (plist, Minput_candidates_start, (void *) win_callback);
-    plist = mplist_add (plist, Minput_candidates_draw, (void *) win_callback);
-    plist = mplist_add (plist, Minput_candidates_done, (void *) win_callback);
-    plist = mplist_add (plist, Minput_set_spot, (void *) win_callback);
-    plist = mplist_add (plist, Minput_toggle, (void *) win_callback);
-    plist = mplist_add (plist, Minput_reset, (void *) win_callback);
+    mplist_put_func (plist, Minput_preedit_start, M17N_FUNC (win_callback));
+    mplist_put_func (plist, Minput_preedit_draw, M17N_FUNC (win_callback));
+    mplist_put_func (plist, Minput_preedit_done, M17N_FUNC (win_callback));
+    mplist_put_func (plist, Minput_status_start, M17N_FUNC (win_callback));
+    mplist_put_func (plist, Minput_status_draw, M17N_FUNC (win_callback));
+    mplist_put_func (plist, Minput_status_done, M17N_FUNC (win_callback));
+    mplist_put_func (plist, Minput_candidates_start, M17N_FUNC (win_callback));
+    mplist_put_func (plist, Minput_candidates_draw, M17N_FUNC (win_callback));
+    mplist_put_func (plist, Minput_candidates_done, M17N_FUNC (win_callback));
+    mplist_put_func (plist, Minput_set_spot, M17N_FUNC (win_callback));
+    mplist_put_func (plist, Minput_toggle, M17N_FUNC (win_callback));
+    mplist_put_func (plist, Minput_reset, M17N_FUNC (win_callback));
   }
 #if 0
   /* This will make the caller of minput_method_open() pazzled.  */
@@ -683,9 +683,9 @@ MSymbol Mxim;
     the byte is bitwise anded by 0x1F and the Control modifier is
     cleared.
 
-    If $EVENT still has modifiers, the name is preceded by "H-"
-    (Hyper), "s-" (Super), "A-" (Alt), "M-" (Meta), "C-" (Control),
-    and/or "S-" (Shift) in this order.
+    If $EVENT still has modifiers, the name is preceded by "S-"
+    (Shift), "C-" (Control), "M-" (Meta), "A-" (Alt), "s-" (Super),
+    and/or "H-" (Hyper) in this order.
 
     For instance, if the keysym name is "a" and the event has Shift,
     Meta, and Hyper modifiers, the resulting name is "M-H-A".
@@ -712,8 +712,8 @@ MSymbol Mxim;
     0x1F Ȥӥåñ̤ and 黻Control ǥեϼ롣
 
     Ǥ $EVENT ˤޤǥեС̾ˤ줾
-    "H-" (Hyper), "s-" (Super), "A-" (Alt), "M-" (Meta), "C-"
-    (Control), "S-" (Shift) ν֤դ
+    "S-" (Shift), "C-" (Control), "M-" (Meta), "A-" (Alt), "s-"
+    (Super), "H-" (Hyper)ν֤դ
     
     ȤСkeysym ̾ "a" ǥ٥Ȥ Shift, Meta, and Hyper 
     ǥեƤС̾ "M-H-A" Ǥ롣
