@@ -344,7 +344,6 @@ MSymbol Mcodeset;
     If the call is successful, mlocale_set () returns an opaque locale
     object that corresponds to the locale.  The name of the locale can
     be acquired by the function mlocale_get_prop ().
-
     Otherwise, it returns NULL.  */
 
 /***ja
@@ -363,7 +362,6 @@ MSymbol Mcodeset;
     ƤӽФСmlocale_set () ϥб opaque 
     륪֥Ȥ֤̾ϴؿ
     mlocale_get_prop () ˤä뤳ȤǤ롣
-
     Ǥʤ NULL ֤
      */
 
@@ -460,7 +458,7 @@ mlocale_get_prop (MLocale *locale, MSymbol key)
     of strftime ().
 
     @seealso
-    strftime ()
+    strftime ().
 */
 /***ja
     @brief դȻ֤եޥåȤ.
@@ -472,7 +470,7 @@ mlocale_get_prop (MLocale *locale, MSymbol key)
      $TM  $FORMAT ΰ̣ strftime () ξƱ
 
     @seealso
-    strftime ()
+    strftime ().
 */
 
 int
