@@ -102,11 +102,11 @@ typedef struct
 {
   /***en Used as the arguments of @c XCreateIC following @c
       XNInputStyle.  If this is zero, ( @c XIMPreeditNothing | @c
-      XIMStatusNothing) is used, and <preedit_attrs> and
-      <status_attrs> are set to @c NULL.  */
+      XIMStatusNothing) is used, and \<preedit_attrs\> and
+      \<status_attrs\> are set to @c NULL.  */
   /***ja @c XCreateIC  @c XNInputStyle ³ȤѤ롣
       ʤС ( @c XIMPreeditNothing | @c XIMStatusNothing) 
-      졢 <preedit_attrs>  <status_attrs>  @c NULL 
+      졢 \<preedit_attrs\>  \<status_attrs\>  @c NULL 
       ꤵ롣 */
 
   XIMStyle input_style;
