@@ -119,25 +119,25 @@ typedef struct
   /***ja հַκݤοʿľĴͤ
       26.6 fractional pixel format ɽΡ  */
   int xoff, yoff;
-  /***en Flag to tell whether the member <code> has already been set
+  /***en Flag to tell whether the member \<code\> has already been set
       to a glyph ID in the font.  */
-  /***ja С <code> ˴˥ ID
+  /***ja С \<code\> ˴˥ ID
       åȤƤ뤫ݤ򼨤ե饰  */
   unsigned encoded : 1;
-  /***en Flag to tell if the metrics of the glyph (members <xadv> thru
-      <rbearing>) are already calculated.  */
-  /***ja С <xadv>  <rbearing>
+  /***en Flag to tell if the metrics of the glyph (members \<xadv\> thru
+      \<rbearing\>) are already calculated.  */
+  /***ja С \<xadv\>  \<rbearing\>
       ޤǤγƥȥå˷׻Ѥݤ򼨤ե饰  */
   unsigned measured : 1;
   /***en Flag to tell if the metrics of the glyph is adjusted,
-      i.e. <xadv> or <yadv> is different from the normal size, or
-      <xoff> or <yoff> is nonzero.  */
+      i.e. \<xadv\> or \<yadv\> is different from the normal size, or
+      \<xoff\> or \<yoff\> is nonzero.  */
   /***ja դΥȥåĴѤߤݤ
       ʤʲΤ1İʾ夬ΩƤ뤳Ȥ򼨤ե饰
-      <xadv> ɸͤȰۤʤ롢
-      <yadv> ɸͤȰۤʤ롢
-      <xoff> Ǥʤ
-      <yoff> Ǥʤ  */
+      \<xadv\> ɸͤȰۤʤ롢
+      \<yadv\> ɸͤȰۤʤ롢
+      \<xoff\> Ǥʤ
+      \<yoff\> Ǥʤ  */
   unsigned adjusted : 1;
   /***en For m17n-lib's internal use only.  */
   /***ja m17n-lib ѡ  */
@@ -178,10 +178,10 @@ typedef struct
   /***en Number of glyphs to go back for drawing a glyph.  */
   /***ja Τ٤տ  */
   short back;
-  /***en If nonzero, the member <xadv> and <yadv> are absolute, i.e.,
+  /***en If nonzero, the member \<xadv\> and \<yadv\> are absolute, i.e.,
       they should not be added to a glyph's origianl advance width and
       height.  */
-  /***ja 󥼥ΤȤС <xadv>  <yadv> ͤǤ롣
+  /***ja 󥼥ΤȤС \<xadv\>  \<yadv\> ͤǤ롣
       ʤͤ򥰥˲ûƤϤʤʤ  */
   unsigned advance_is_absolute : 1;
   /***en Should be set to 1 iff at least one of the other members has
@@ -296,25 +296,25 @@ typedef struct _MFLTFont
   int x_ppem, y_ppem;
 
   /***en Callback function to get glyph IDs for glyphs between FROM
-     (inclusive) and TO (exclusive) of GSTRING.  If the member <encoded>
-     of a glyph is zero, the member <code> of that glyph is a character
+     (inclusive) and TO (exclusive) of GSTRING.  If the member \<encoded\>
+     of a glyph is zero, the member \<code\> of that glyph is a character
      code.  The function must convert it to the glyph ID of FONT.  */
   /***ja GSTRING  FROM  TO ľޤǤγƥդб륰
       ID뤿 callback ؿ⤷륰դΥС
-      <encoded>ʤСΥդΥС <code> ʸɤ
+      \<encoded\>ʤСΥդΥС \<code\> ʸɤ
       롣δؿϤʸɤ FONT Υ IDѴʤƤ
       ʤʤ  */
   int (*get_glyph_id) (struct _MFLTFont *font, MFLTGlyphString *gstring,
 		       int from, int to);
 
   /***en Callback function to get metrics of glyphs between FROM
-     (inclusive) and TO (exclusive) of GSTRING.  If the member <measured>
-     of a glyph is zero, the function must set the members <xadv>, <yadv>,
-     <ascent>, <descent>, <lbearing>, and <rbearing> of the glyph.  */
+     (inclusive) and TO (exclusive) of GSTRING.  If the member \<measured\>
+     of a glyph is zero, the function must set the members \<xadv\>, \<yadv\>,
+     \<ascent\>, \<descent\>, \<lbearing\>, and \<rbearing\> of the glyph.  */
   /***ja GSTRING  FROM  TOľޤǤγƥդбȥ
       뤿 callback ؿ⤷륰դΥС
-      <measured>ʤСδؿϤΥդΥС <xadv>,
-      <yadv>, <ascent>, <descent>, <lbearing>,  <rbearing>򥻥
+      \<measured\>ʤСδؿϤΥդΥС \<xadv\>,
+      \<yadv\>, \<ascent\>, \<descent\>, \<lbearing\>,  \<rbearing\>򥻥
       ȤʤФʤʤ  */
   int (*get_metrics) (struct _MFLTFont *font, MFLTGlyphString *gstring,
 		     int from, int to);
