@@ -512,11 +512,11 @@ typedef struct
 
   /***en If nonzero, draw an M-text two-dimensionally, i.e., newlines
       in M-text breaks lines and the following characters are drawn in
-      the next line.  If <format> is non-NULL, and the function
+      the next line.  If \<format\> is non-NULL, and the function
       returns nonzero line width, a line longer than that width is
       also broken.  */
   /***ja 0 ǤʤСM-text 򣲼Ūˡʤ M-text  
-      newline ǲԤ³ʸϼιԤɽ롣⤷ <format>  
+      newline ǲԤ³ʸϼιԤɽ롣⤷ \<format\>  
       NULL Ǥʤδؿ 0 Ǥʤ֤СĹԤԤ롣  */
   unsigned two_dimensional : 1;
 
@@ -565,9 +565,9 @@ typedef struct
 
   /***en If nonzero, the value specifies how many pixels each line can
       occupy on the display.  The value zero means that there is no
-      limit.  It is ignored if <format> is non-NULL.  */
+      limit.  It is ignored if \<format\> is non-NULL.  */
   /***ja 0 ǤʤСͤϤΥǥץ쥤ǳƹԤ뤳ȤΤǤԥ򼨤
-      0 ϸꤵʤȤ̣롣<format>  NULL Ǥʤ̵뤵롣   */
+      0 ϸꤵʤȤ̣롣\<format\>  NULL Ǥʤ̵뤵롣   */
   unsigned int max_line_width;
 
   /***en If nonzero, the value specifies the distance between tab
@@ -587,7 +587,7 @@ typedef struct
 
       The indentation specifies how many pixels the first glyph of
       each line is shifted to the right (if the member
-      <orientation_reversed> is zero) or to the left (otherwise).  If
+      \<orientation_reversed\> is zero) or to the left (otherwise).  If
       the value is negative, each line is shifted to the reverse
       direction.
 
@@ -598,13 +598,13 @@ typedef struct
       character, and incremented each time when a long line is broken
       because of the width limit.
 
-      This has an effect only when <two_dimensional> is nonzero.  */
+      This has an effect only when \<two_dimensional\> is nonzero.  */
   /***ja 0 ǤʤСͤϴؿǤꡢδؿϹֹ LINE Ⱥɸ Y 
       ˴ŤƳƹԤΥǥȤȺ׻줾INDENT 
       WIDTH ǻؤ¸롣
 
       ǥȤϡƹԤκǽΥդ򱦡ʥ 
-      <orientation_reversed>  0 
+      \<orientation_reversed\>  0 
       λˤ뤤Ϻʤʳλˤ˲ԥ뤺餹ꤹ롣ͤʤеˤ餹
 
       ϡƹԤǥץ쥤뤳ȤΤǤԥκͤǤ롣ͤ
@@ -613,7 +613,7 @@ typedef struct
       LINE  Y ϲʸˤäƹԤޤäݤˤ 0 
       ˥ꥻåȤ졢ĹԤ¤ˤäƲԤ뤿Ӥ 1 䤵롣
 
-       <two_dimensional>  0 ǤʤˤΤͭǤ롣  */
+       \<two_dimensional\>  0 ǤʤˤΤͭǤ롣  */
   void (*format) (int line, int y, int *indent, int *width);
 
   /***en If non-NULL, the value is a function that calculates a line
@@ -622,7 +622,7 @@ typedef struct
       last one that fits within the limit.  FROM is the position of the
       first character of the line, and TO is the position of the last
       character displayed on the line if there were not width limit.
-      LINE and Y are the same as the arguments to <format>.
+      LINE and Y are the same as the arguments to \<format\>.
 
       The function must return a character position to break the
       line.
@@ -635,7 +635,7 @@ typedef struct
       POS Ϻ˼ޤǸʸμʸΰ֤Ǥ롣FROM
       ϹԤκǽʸΰ֡TO 
       ϺꤵƤʤФιԤɽǸʸΰ֤Ǥ롣LINE 
-       Y  <format> ΰƱͤǤ롣
+       Y  \<format\> ΰƱͤǤ롣
 
       δؿϹԤʸ֤֤ʤƤϤʤʤޤ MT ѹƤϤʤʤ
 
@@ -648,29 +648,29 @@ typedef struct
   /***en Specifies the character position to display a cursor.  If it
       is greater than the maximum character position, the cursor is
       displayed next to the last character of an M-text.  If the value
-      is negative, even if <cursor_width> is nonzero, cursor is not
+      is negative, even if \<cursor_width\> is nonzero, cursor is not
       displayed.  */
   /***ja ɽʸ֤򼨤ʸ֤礭С 
       M-text κǸʸ٤ɽ롣ʤС
-      <cursor_width>  0 ǤʤƤ⥫ɽʤ
+      \<cursor_width\>  0 ǤʤƤ⥫ɽʤ
         */
   int cursor_pos;
 
   /***en If nonzero, display a cursor at the character position
-      <cursor_pos>.  If the value is positive, it is the pixel width
+      \<cursor_pos\>.  If the value is positive, it is the pixel width
       of the cursor.  If the value is negative, the cursor width is
       the same as the underlining glyph(s).  */
-  /***ja 0 ǤʤС<cursor_pos> ˥ɽ롣
+  /***ja 0 ǤʤС\<cursor_pos\> ˥ɽ롣
       ͤʤСϤ͡ʥԥñ̡ˤǤ롣
       ʤСΤ륰դƱǤ롣  */
   int cursor_width;
 
-  /***en If nonzero and <cursor_width> is also nonzero, display double
-      bar cursors; at the character position <cursor_pos> and at the
+  /***en If nonzero and \<cursor_width\> is also nonzero, display double
+      bar cursors; at the character position \<cursor_pos\> and at the
       logically previous character.  Both cursors have one pixel width
       with horizontal fringes at upper or lower positions.  */
-  /***ja If 0 Ǥʤ <cursor_width>  0 ǤʤССʸ
-      <cursor_pos> ŪˤˤʸΣɽ롣
+  /***ja If 0 Ǥʤ \<cursor_width\>  0 ǤʤССʸ
+      \<cursor_pos\> ŪˤˤʸΣɽ롣
       Ȥ⣱ԥǡ夫˿ʿξ꤬Ĥ*/
   int cursor_bidi;
 
@@ -832,10 +832,10 @@ typedef struct
   MSymbol font_type;
 
   /***en Pointer to the font structure.  The actual type is
-      (XFontStruct *) if <font_type> member is Mx, FT_Face if
-      <font_type> member is Mfreetype, and (XftFont *) if <font_type>
+      (XFontStruct *) if \<font_type\> member is Mx, FT_Face if
+      \<font_type\> member is Mfreetype, and (XftFont *) if \<font_type\>
       member is Mxft.  */
-  /***ja եȤι¤ΤؤΥݥ󥿡ºݤη <font_type> Ф
+  /***ja եȤι¤ΤؤΥݥ󥿡ºݤη \<font_type\> Ф
       Mx ʤ (XFontStruct *) Mfreetype ʤ FT_FaceMxft 
       ʤ (XftFont *) */
   void *fontp;
@@ -872,15 +872,15 @@ typedef struct
 
   /***en Pointer to a face object.  Each property of the face, if not
       Mnil, overrides the same property of face(s) specified as a text
-      property in <mt>.  */
+      property in \<mt\>.  */
   /***ja ե֥ȤؤΥݥ󥿡եγƥץѥƥ 
-      Mnil Ǥʤ <mt> ǻꤵ줿եƱץѥƥͥ褹*/
+      Mnil Ǥʤ \<mt\> ǻꤵ줿եƱץѥƥͥ褹*/
   MFace *face;
 
-  /***en Pointer to a draw control object.  The M-text <mt> is drawn
+  /***en Pointer to a draw control object.  The M-text \<mt\> is drawn
       by mdraw_text_with_control () with this control object.  */
   /***ja ɽ楪֥ȤؤΥݥ󥿡 mdraw_text_with_control () 
-      ϤΥ֥ȤѤ M-text <mt> ɽ롣  */
+      ϤΥ֥ȤѤ M-text \<mt\> ɽ롣  */
   MDrawControl *control;
 
 } MDrawTextItem;
