@@ -679,7 +679,7 @@ typedef struct
       ending by them.  On encoding, produce byte sequence according to
       @c endian with heading BOM.
 
-      If <code_unit_bits> is 8, the value has no meaning.  */
+      If \<code_unit_bits\> is 8, the value has no meaning.  */
 
   /***ja
       Ƭ BOM (Хȥޡ) μ갷ꤹ롣ͤ 0,
@@ -702,12 +702,12 @@ typedef struct
       Specify the endian type.  The value must be 0 or 1.  0 means
       little endian, and 1 means big endian.
 
-      If <code_unit_bits> is 8, the value has no meaning.  */
+      If \<code_unit_bits\> is 8, the value has no meaning.  */
   /***ja
       ǥΥפꤹ롣ͤ 0  1 Ǥꡢ0 
       ʤХȥ륨ǥ1 ʤХӥåǥǤ롣
 
-      <code_unit_bits>  8 ξˤϡͤϰ̣ʤ
+      \<code_unit_bits\>  8 ξˤϡͤϰ̣ʤ
   */
   int endian;
 } MCodingInfoUTF;
@@ -890,7 +890,7 @@ typedef struct MInputDriver
       @brief Open an input method.
 
       This function opens the input method $IM.  It is called from the
-      function minput_open_im () after all member of $IM but <info>
+      function minput_open_im () after all member of $IM but \<info\>
       set.  If opening $IM succeeds, it returns 0.  Otherwise, it
       returns -1.  The function can setup $IM->info to keep various
       information that is referred by the other driver functions.  */
@@ -898,7 +898,7 @@ typedef struct MInputDriver
   /***ja
       @brief ϥ᥽åɤ򥪡ץ󤹤.
 
-      δؿϡϥ᥽å $IM 򥪡ץ󤹤롣$IM  <info> 
+      δؿϡϥ᥽å $IM 򥪡ץ󤹤롣$IM  \<info\> 
       ʳСåȤ줿ǡؿ minput_open_im () 
       ƤФ롣$IM 򥪡ץǤ 0 򡢤Ǥʤ -1֤
       δؿ $IM->info 
@@ -933,7 +933,7 @@ typedef struct MInputDriver
 
       This function creates the input context $IC.  It is called from
       the function minput_create_ic () after all members of $IC but
-      <info> are set.  If creating $IC succeeds, it returns 0.
+      \<info\> are set.  If creating $IC succeeds, it returns 0.
       Otherwise, it returns -1.  The function can setup $IC->info to
       keep various information that is referred by the other driver
       functions.  */
@@ -942,7 +942,7 @@ typedef struct MInputDriver
       @brief ϥƥȤ.
 
       δؿϥƥ $IC 롣
-      $IC  <info> ʳСåȤ줿ǡؿ
+      $IC  \<info\> ʳСåȤ줿ǡؿ
       minput_create_ic () ƤФ롣
       $IC Ǥ 0 򡢤Ǥʤ -1 ֤
       δؿ $IC->info ꤷơ¾Υɥ饤дؿ黲Ȥݻ뤳ȤǤ롣  */
@@ -982,7 +982,7 @@ typedef struct MInputDriver
 
       It may update $IC->status, $IC->preedit, $IC->cursor_pos,
       $IC->ncandidates, $IC->candidates, and $IC->produced if that is
-      necessary for the member <callback>.
+      necessary for the member \<callback\>.
 
       The meaning of $ARG depends on the input method river.  See the
       documentation of @c minput_default_driver and @c
@@ -998,7 +998,7 @@ typedef struct MInputDriver
       ϥ᥽åɤ˵ۼƥƥȤʤäˤϡ 
       1 ֤Ǥʤ 0 ֤
 
-       <callback> ɬפǤС$IC->status, $IC->preedit,
+       \<callback\> ɬפǤС$IC->status, $IC->preedit,
       $IC->cursor_pos, $IC->ncandidates, $IC->candidates,
       $IC->produced 򹹿Ǥ롣
 
@@ -1127,9 +1127,9 @@ struct MInputMethod
   /***ja minput_open_im () Ϥ  */
   void *arg;
 
-  /***en Pointer to extra information that <driver>.open_im ()
+  /***en Pointer to extra information that \<driver\>.open_im ()
       setups. */
-  /***ja <driver>.open_im () ꤹɲþؤΥݥ󥿡 */
+  /***ja \<driver\>.open_im () ꤹɲþؤΥݥ󥿡 */
   void *info;
 };
 
@@ -1208,8 +1208,8 @@ struct MInputContext
     /***ja ݥåȾ M-textޤ NULL.  */
     MText *mt;
 
-    /***en Character position in <mt> at the spot.  */
-    /***ja <mt> ˤ륹ݥåȤʸ.  */
+    /***en Character position in \<mt\> at the spot.  */
+    /***ja \<mt\> ˤ륹ݥåȤʸ.  */
     int pos;
   } spot;
 
@@ -1234,8 +1234,8 @@ struct MInputContext
   MText *status;
 
   /***en The function <im>->driver.filter () sets the value to 1 when
-      it changes <status>.  */
-  /***ja ؿ <im>->driver.filter () ϡ<status> Ѥݤˤͤ 1 
+      it changes \<status\>.  */
+  /***ja ؿ <im>->driver.filter () ϡ\<status\> Ѥݤˤͤ 1 
       ꤹ롣  */
   int status_changed;
 
@@ -1246,18 +1246,18 @@ struct MInputContext
   MText *preedit;
 
   /***en The function <im>->driver.filter () sets the value to 1 when
-      it changes <preedit>.  */
-  /***ja ؿ <im>->driver.filter () ϡ<preedit> Ѥݤˤͤ 
+      it changes \<preedit\>.  */
+  /***ja ؿ <im>->driver.filter () ϡ\<preedit\> Ѥݤˤͤ 
       1 ꤹ롣  */
   int preedit_changed;
 
-  /***en Cursor position of <preedit>.  */
-  /***ja <preedit>Υ  */
+  /***en Cursor position of \<preedit\>.  */
+  /***ja \<preedit\>Υ  */
   int cursor_pos;
 
   /***en The function <im>->driver.filter () sets the value to 1 when
-      it changes <cursor_pos>.  */
-  /***ja ؿ <im>->driver.filter () ϡ<cursor_pos> Ѥݤˤͤ 
+      it changes \<cursor_pos\>.  */
+  /***ja ؿ <im>->driver.filter () ϡ\<cursor_pos\> Ѥݤˤͤ 
       1 ꤹ롣  */
   int cursor_pos_changed;
 
@@ -1284,8 +1284,8 @@ struct MInputContext
   int candidate_index;
 
   /***en Start and the end positions of the preedit text where
-       <candidate_list> corresponds to.  */
-  /***ja preedit ƥǡ<candidate_list>бǽȺǸΰ֡
+       \<candidate_list\> corresponds to.  */
+  /***ja preedit ƥǡ\<candidate_list\>бǽȺǸΰ֡
        */
   int candidate_from, candidate_to;
 
@@ -1300,9 +1300,9 @@ struct MInputContext
 
   /***en The function <im>->driver.filter () sets the value to bitwise
       OR of @c enum @c MInputCandidatesChanged when it changed any of
-      the above members (<candidate_XXX>), and sets the value to 0
+      the above members (\<candidate_XXX\>), and sets the value to 0
       otherwise.  */
-  /***ja ؿ <im>->driver.filter () ϡ嵭Υ <candidate_XXX>
+  /***ja ؿ <im>->driver.filter () ϡ嵭Υ \<candidate_XXX\>
       ΣĤǤѹݤˤϡͤ @c enum @c
       MInputCandidatesChanged Υӥåñ̤Ǥ OR ꤹ롣
       Ǥʤ 0 ꤹ롣 */
