@@ -1583,7 +1583,7 @@ mplist_value (MPlist *plist)
     Msymbol, @c Minteger, @c Mtext, @c Mplist
 
     In an ascii-character-sequence, a backslash (\) is used as the escape
-    character, which means that, for instance, <tt>"abc\ def"</tt>
+    character, which means that, for instance, <tt>abc\ def</tt>
     produces a symbol whose name is of length seven with the fourth
     character being a space.  */
 /***ja
@@ -1608,7 +1608,7 @@ mplist_value (MPlist *plist)
     @c Mplist Τ줫ƤƤ롣
 
     ʸǤϡХåå (\) ʸȤѤ롣Ȥ
-    <tt>"abc\ def"</tt>  4 ʸܤʸǤĹ 7 
+    <tt>abc\ def</tt>  4 ʸܤʸǤĹ 7 
     Ǥ̾ĥܥ롣   */
 
 MPlist *
